==> varbase-8.x-8.11.tar.gz: varbase/README.md <==
[![Vardot](https://circleci.com/gh/Vardot/varbase/tree/8.x-8.x.svg?style=shield)](https://app.circleci.com/pipelines/github/Vardot/varbase/334/workflows/532cc770-dbd4-4ab7-8b24-aa3661fa7901) Varbase 8.8.11

[![](https://www.drupal.org/files/styles/grid-3/public/project-images/Medium-Logo%20Color%20with%20padding.png)](https://www.drupal.org/project/varbase)

## Varbase: The Ultimate Drupal 8 CMS Starter Kit (Bootstrap Ready)

The powerful Drupal distribution for faster development, with editor experience
in mind. Brought to you by [Vardot](https://www.vardot.com/).

Varbase is an enhanced Drupal distribution with a lot of necessities.
Necessities are all the modules, features, configurations that we include
in every project.


## It's made with the following benefits in mind:

* Speeds up development.
* Offers standardized configuration and best-practices.
* Comes with a lot of needed functionalities/modules for every-day Drupal site.
* [Tested, tested, and tested.](https://travis-ci.org/Vardot/varbase/builds)

Starting a new project? Consider Varbase for Drupal 8.
Installing Varbase 8.x-8.x comes with several extra automated installation
steps, to take full advantage of Varbase, other than the Drupal 8 installation
instructions.


# Install with Composer

To install the most recent stable release of Varbase 8.8.x run this command:
```
composer create-project vardot/varbase-project:^8.8.11 PROJECT_DIR_NAME --no-dev --no-interaction
```

To install the dev version of Varbase 8.8.x run this command:
```
composer create-project vardot/varbase-project:8.8.x-dev PROJECT_DIR_NAME --stability dev --no-interaction
```

## [Create a new Vartheme sub theme for a project](https://github.com/Vardot/varbase/tree/8.x-8.x/scripts/README.md)

## [Automated Functional Testing](https://github.com/Vardot/varbase/blob/8.x-8.x/tests/README.md)

## [Varbase Gherkin features](https://github.com/Vardot/varbase/blob/8.x-8.x/tests/features/varbase/README.md)

## [Varbase 8.8.x Developer Guide](https://docs.varbase.vardot.com)

## [CHANGELOG for Varbase](https://github.com/Vardot/varbase/blob/8.x-8.x/CHANGELOG.md)

## [General instructions on how to update Varbase](https://github.com/Vardot/varbase/blob/8.x-8.x/UPDATE.md)

==> varbase-8.x-8.12.tar.gz: varbase/README.md <==
[![Vardot](https://circleci.com/gh/Vardot/varbase/tree/8.x-8.x.svg?style=shield)](https://app.circleci.com/pipelines/github/Vardot/varbase/388/workflows/45f9bac1-501d-4a8b-8740-55faccb2529f) Varbase 8.8.12

[![](https://www.drupal.org/files/styles/grid-3/public/project-images/Medium-Logo%20Color%20with%20padding.png)](https://www.drupal.org/project/varbase)

## Varbase: The Ultimate Drupal 8 CMS Starter Kit (Bootstrap Ready)

The powerful Drupal distribution for faster development, with editor experience
in mind. Brought to you by [Vardot](https://www.vardot.com/).

Varbase is an enhanced Drupal distribution with a lot of necessities.
Necessities are all the modules, features, configurations that we include
in every project.


## It's made with the following benefits in mind:

* Speeds up development.
* Offers standardized configuration and best-practices.
* Comes with a lot of needed functionalities/modules for every-day Drupal site.
* [Tested, tested, and tested.](https://app.circleci.com/pipelines/github/Vardot/varbase?branch=8.x-8.x)

Starting a new project? Consider Varbase for Drupal 8.
Installing Varbase 8.x-8.x comes with several extra automated installation
steps, to take full advantage of Varbase, other than the Drupal 8 installation
instructions.


# Install with Composer

To install the most recent stable release of Varbase 8.8.x run this command:
```
composer create-project vardot/varbase-project:^8.8.12 PROJECT_DIR_NAME --no-dev --no-interaction
```

To install the dev version of Varbase 8.8.x run this command:
```
composer create-project vardot/varbase-project:8.8.x-dev PROJECT_DIR_NAME --stability dev --no-interaction
```

## [Create a new Vartheme sub theme for a project](https://github.com/Vardot/varbase/tree/8.x-8.x/scripts/README.md)

## [Automated Functional Testing](https://github.com/Vardot/varbase/blob/8.x-8.x/tests/README.md)

## [Varbase Gherkin features](https://github.com/Vardot/varbase/blob/8.x-8.x/tests/features/varbase/README.md)

## [Varbase 8.8.x Developer Guide](https://docs.varbase.vardot.com)

## [CHANGELOG for Varbase](https://github.com/Vardot/varbase/blob/8.x-8.x/CHANGELOG.md)

## [General instructions on how to update Varbase](https://github.com/Vardot/varbase/blob/8.x-8.x/UPDATE.md)
